var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
import React from 'react';
import FrcContext from '../context/frc';
import { getId, getFallbackBoolean, getDisplayName, shouldShowErrors, } from '../utils';
/**
 * withFRC HOC
 *
 * This HOC provides shared code for our form components.
 *
 * We use this to merge props set using our FrcContext, so that
 * we can set commonly used props on an enclosing component.
 *
 * This allows us to set these properties 'as a whole' for each component in the
 * the form, while retaining the ability to override the prop on a per-component
 * basis.
 */
// eslint-disable-next-line @typescript-eslint/explicit-function-return-type
var withFRC = function (Component) {
    var _a;
    var result = (_a = /** @class */ (function (_super) {
            __extends(FrcWrapper, _super);
            function FrcWrapper(props) {
                return _super.call(this, props) || this;
            }
            FrcWrapper.prototype.render = function () {
                var _a = this.context, contextLayout = _a.layout, contextValidateBeforeSubmit = _a.validateBeforeSubmit, contextValidatePristine = _a.validatePristine;
                var _b = this.props, 
                /* eslint-disable @typescript-eslint/no-unused-vars */
                errorMessage = _b.errorMessage, hasValue = _b.hasValue, innerRef = _b.innerRef, isRequired = _b.isRequired, isValidValue = _b.isValidValue, resetValue = _b.resetValue, setValidations = _b.setValidations, showError = _b.showError, showRequired = _b.showRequired, validationError = _b.validationError, validationErrors = _b.validationErrors, validations = _b.validations, 
                /* eslint-enable @typescript-eslint/no-unused-vars */
                isFormDisabled = _b.isFormDisabled, isFormSubmitted = _b.isFormSubmitted, isPristine = _b.isPristine, isValid = _b.isValid, setValue = _b.setValue, propValidateBeforeSubmit = _b.validateBeforeSubmit, propValidatePristine = _b.validatePristine, propLayout = _b.layout, propDisabled = _b.disabled, propId = _b.id, propLabel = _b.label, propName = _b.name, componentRef = _b.componentRef, props = __rest(_b, ["errorMessage", "hasValue", "innerRef", "isRequired", "isValidValue", "resetValue", "setValidations", "showError", "showRequired", "validationError", "validationErrors", "validations", "isFormDisabled", "isFormSubmitted", "isPristine", "isValid", "setValue", "validateBeforeSubmit", "validatePristine", "layout", "disabled", "id", "label", "name", "componentRef"]);
                var validatePristine = getFallbackBoolean(propValidatePristine, contextValidatePristine, false);
                var validateBeforeSubmit = getFallbackBoolean(propValidateBeforeSubmit, contextValidateBeforeSubmit, true);
                var showErrors = shouldShowErrors(isPristine, isFormSubmitted, isValid, validatePristine, validateBeforeSubmit);
                var layout = propLayout || contextLayout;
                var newProps = {
                    id: getId(propId || '', propLabel || '', propName),
                    label: propLabel,
                    name: propName,
                    ref: componentRef,
                    disabled: isFormDisabled || propDisabled || false,
                    layout: layout,
                    showErrors: showErrors,
                    onSetValue: setValue,
                };
                return React.createElement(Component, __assign({}, props, newProps));
            };
            return FrcWrapper;
        }(React.Component)),
        _a.displayName = "withFRC(" + getDisplayName(Component) + ")",
        _a.contextType = FrcContext,
        _a);
    return result;
};
export default withFRC;
//# sourceMappingURL=component.js.map